@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: dns.cpp,v 1.11 2006/11/06 16:54:51 vkurland Exp $
+  $Id: dns.cpp,v 1.12 2007/08/02 05:19:28 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -67,7 +67,11 @@ const size_t DNS::RSP_BUF_SIZE=64*1024;
 Mutex *DNS::gethostbyname_mutex;
 Mutex *DNS::gethostbyaddr_mutex;
 
-void libfwbuilder::init_dns() throw(FWException)
+
+namespace libfwbuilder
+{
+
+void init_dns() throw(FWException)
 {
     DNS::init();
 
@@ -85,6 +89,85 @@ void libfwbuilder::init_dns() throw(FWException)
 "Lightweight resolver library test failed; perhaps lwresd is not running.\nDNS queries won't work.");
 
 #endif
+}
+
+void* DNS_bulkBackResolve_Thread(void *args)
+{
+    std::ostringstream str;
+    void **void_pair=(void**)args;
+    DNS_bulkBackResolve_query *p      = static_cast<DNS_bulkBackResolve_query*>(void_pair[0]);
+    Logger                    *logger = static_cast<Logger *>(void_pair[1]);
+    SyncFlag            *stop_program = static_cast<SyncFlag*>(void_pair[2]);
+    try 
+    {
+        while( true )
+        {
+            stop_program->lock();
+            if ( stop_program->peek() )
+            {
+                stop_program->unlock();
+                return NULL;
+            }
+            stop_program->unlock();
+
+            p->queue_mutex.lock();
+            if(p->ips.empty())
+            {
+                p->queue_mutex.unlock();
+                break;
+            }
+            IPAddress j=p->ips.front();
+            p->ips.pop();
+            p->queue_mutex.unlock();
+        
+	    str << "Trying " << j.toString() 
+                << ";   " << int(p->ips.size()) << " more in the queue\n";
+            *logger << str;
+
+            try
+            {
+
+                HostEnt he=DNS::getHostByAddr(j, p->retries, p->timeout);
+                std::ostringstream str;
+                str << "Resolved  " << j.toString() << ": " << he.name << "\n";
+                *logger << str;
+                p->result_mutex.lock();
+                p->result[j]=he;
+                p->result_mutex.unlock();
+            } catch(FWException &ex)
+            {
+                std::ostringstream str;
+                str << "Could not resolve address " << j.toString() 
+		    << " to a host name, will use generic name\n";
+                *logger << str;
+                p->failed_mutex.lock();
+                p->failed.insert(j);
+                p->failed_mutex.unlock();
+            }
+        }
+    } 
+    catch (FWException &ex)
+    {
+        // do nothing, just break the "while" loop
+    }
+
+//#ifdef DNS_DEBUG
+    str << " Worker thread exiting. " << p->running_count << " threads left.\n";
+    *logger << str;
+//#endif
+
+    p->running_mutex.lock   ();
+    p->running_count--;
+    p->running_cond.signal  ();
+    p->running_mutex.unlock ();
+
+//#ifdef DNS_DEBUG
+    str << " Worker thread terminated.\n";
+    *logger << str;
+//#endif
+
+    return NULL;
+}
 
 }
 
@@ -814,84 +897,6 @@ DNS_bulkBackResolve_query::~DNS_bulkBackResolve_query()
     pthread_attr_destroy(&tattr);
 }
 
-void* libfwbuilder::DNS_bulkBackResolve_Thread(void *args)
-{
-    std::ostringstream str;
-    void **void_pair=(void**)args;
-    DNS_bulkBackResolve_query *p      = static_cast<DNS_bulkBackResolve_query*>(void_pair[0]);
-    Logger                    *logger = static_cast<Logger *>(void_pair[1]);
-    SyncFlag            *stop_program = static_cast<SyncFlag*>(void_pair[2]);
-    try 
-    {
-        while( true )
-        {
-            stop_program->lock();
-            if ( stop_program->peek() )
-            {
-                stop_program->unlock();
-                return NULL;
-            }
-            stop_program->unlock();
-
-            p->queue_mutex.lock();
-            if(p->ips.empty())
-            {
-                p->queue_mutex.unlock();
-                break;
-            }
-            IPAddress j=p->ips.front();
-            p->ips.pop();
-            p->queue_mutex.unlock();
-        
-	    str << "Trying " << j.toString() 
-                << ";   " << int(p->ips.size()) << " more in the queue\n";
-            *logger << str;
-
-            try
-            {
-
-                HostEnt he=DNS::getHostByAddr(j, p->retries, p->timeout);
-                std::ostringstream str;
-                str << "Resolved  " << j.toString() << ": " << he.name << "\n";
-                *logger << str;
-                p->result_mutex.lock();
-                p->result[j]=he;
-                p->result_mutex.unlock();
-            } catch(FWException &ex)
-            {
-                std::ostringstream str;
-                str << "Could not resolve address " << j.toString() 
-		    << " to a host name, will use generic name\n";
-                *logger << str;
-                p->failed_mutex.lock();
-                p->failed.insert(j);
-                p->failed_mutex.unlock();
-            }
-        }
-    } 
-    catch (FWException &ex)
-    {
-        // do nothing, just break the "while" loop
-    }
-
-//#ifdef DNS_DEBUG
-    str << " Worker thread exiting. " << p->running_count << " threads left.\n";
-    *logger << str;
-//#endif
-
-    p->running_mutex.lock   ();
-    p->running_count--;
-    p->running_cond.signal  ();
-    p->running_mutex.unlock ();
-
-//#ifdef DNS_DEBUG
-    str << " Worker thread terminated.\n";
-    *logger << str;
-//#endif
-
-    return NULL;
-}
-
 void DNS_bulkBackResolve_query::run_impl(Logger *logger,SyncFlag *stop_program) throw(FWException)
 {
     queue_mutex.lock();
@@ -971,4 +976,3 @@ void DNS_bulkBackResolve_query::run_impl(Logger *logger,SyncFlag *stop_program)
         throw FWException("Some of IPs did not resolve");
 }
 
-
